﻿using C1.Xaml.Pdf;
using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Runtime.InteropServices.WindowsRuntime;
using System.Threading.Tasks;
using Windows.Foundation;
using Windows.Foundation.Collections;
using Windows.Storage;
using Windows.Storage.Pickers;
using Windows.UI.Popups;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Controls.Primitives;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Input;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Media.Imaging;
using Windows.UI.Xaml.Navigation;

// The Blank Page item template is documented at http://go.microsoft.com/fwlink/?LinkId=234238

namespace PdfExportUI_WinRT
{
    /// <summary>
    /// An empty page that can be used on its own or navigated to within a Frame.
    /// </summary>
    public sealed partial class MainPage : Page
    {
        public MainPage()
        {
            this.InitializeComponent();

        }

        private async void btnRender_Click(object sender, RoutedEventArgs e)
        {
            FileSavePicker savePicker = new FileSavePicker();
            savePicker.SuggestedStartLocation = PickerLocationId.DocumentsLibrary;
            savePicker.FileTypeChoices.Add("PDF (*.pdf)", new List<string>(new string[] { ".pdf" }));
            savePicker.DefaultFileExtension = ".pdf";
            StorageFile file = await savePicker.PickSaveFileAsync();
            if(file != null)
            {
                // create document
                var pdf = new C1PdfDocument(PaperKind.Letter);
                pdf.Clear();

                // set document info
                var di = pdf.DocumentInfo;
                di.Author = "ComponentOne";
                di.Subject = "C1.Xaml.Pdf demo.";
                di.Title = "Export UI to PDF";

                // create a bitmap from the UI element
                var img = await CreateBitmap(panel);

                // draw bitmap to PDF
                pdf.DrawImage(img, pdf.PageRectangle, ContentAlignment.TopLeft, Stretch.None);

                // save PDF file
                await pdf.SaveAsync(file);

                // notify user it's saved
                MessageDialog dialog = new MessageDialog("File saved!");
                await dialog.ShowAsync();
            }
            
        }

        async public Task<WriteableBitmap> CreateBitmap(FrameworkElement element)
        {
            // render element to image (WinRT)
            var renderTargetBitmap = new RenderTargetBitmap();
            await renderTargetBitmap.RenderAsync(element);
            var wb = new WriteableBitmap(renderTargetBitmap.PixelWidth, renderTargetBitmap.PixelHeight);
            (await renderTargetBitmap.GetPixelsAsync()).CopyTo(wb.PixelBuffer);
            var rect = new Rect(0, 0, renderTargetBitmap.PixelWidth, renderTargetBitmap.PixelHeight);

            return wb;
        }
    }
}
